@@ -60,14 +60,17 @@ class BusAdapter(object):
         self.resultDeliveryFunc = functools.partial(self._awaitSynchronousReturn)
         self.topicThreads = {}
         
+        self.defaultResultCallback = functools.partial(self._defaultResultCallback)
+        
         self.rserver =  redis_lib.StrictRedis(host=host, port=port, db=db)
         self.pub_sub = self.rserver.pubsub()
         
     def publish(self, busMessage, sync=False, timeout=None, block=True, auth=None):
         '''
         Main method for publishing a message. 
-        If you are publishing a response to a synchronous call, set 
-        the topicName in the BusMessage instance to self.get_responseTopic(incoming-bus-msg))
+        If you are publishing a response to a synchronous call, use
+        self.makeResponseMsg(incoming-bus-msg) to create the busMessage that you
+        pass into this method.
         
         :param busMessage: A BusMessage object.
         :type busMessage: BusMessage
@@ -109,7 +112,7 @@ class BusAdapter(object):
         msgDict = dict(zip(['id', 'time', 'content'],
                            [msgUuid, int(time.time()), msg]))
 
-        # If synchronous operation requested, wait for response:
+        # If synchronous operation requested, wait for response from recipient:
         if sync:
             returnTopic = self.getResponseTopic(busMessage)
             # Post the request, and get the response in one command:
@@ -142,9 +145,10 @@ class BusAdapter(object):
         calls your handler faster, but while your handler has control, the 
         underlying communication mechanism cannot process other messages.
         
-        If deliveryCallback is None, then method _deliverResult() will be called
+        If deliveryCallback is None, then method _defaultResultCallback() will be called
         when a message arrives. That method is intended to be a 
-        placeholder with no side effects.
+        placeholder with no side effects, except that it prints
+        information about the message. Just used for testing.
         
         The context is any object or structure that is
         meaningful to the delivery callback. This could be the instance
@@ -162,8 +166,10 @@ class BusAdapter(object):
                  
         :param topicIdentifier: name or regex Python Pattern instance of topic(s) to listen for.
         :type topicIdentifier: {string | Pattern}
-        :param deliveryCallable: a callable that takes a BusMessage instance 
-        :type deliveryCallable: callable
+        :param deliveryCallable: a callable that takes a BusMessage instance.
+                if None, a default callback is used that just prints information
+                from the incoming message.
+        :type deliveryCallable: {callable || None}
         :param threaded: if True, messages are delivered through a thread via a queue.
             The thread invokes deliveryCallable
         :type threaded: boolean
@@ -172,7 +178,7 @@ class BusAdapter(object):
         '''
         
         if deliveryCallable is None:
-            deliveryCallable = self.resultCallback
+            deliveryCallable = self.defaultResultCallback
         elif type(deliveryCallable) != types.FunctionType and type(deliveryCallable) != functools.partial:
             raise ValueError("Parameter deliveryCallback must be a function, was of type %s" % type(deliveryCallable))            
 
@@ -209,6 +215,21 @@ class BusAdapter(object):
             topic_spec = {pattern_str : delivery_queue if threaded else deliveryCallable}
             self.pub_sub.psubscribe(context, **topic_spec)
 
+    def _defaultResultCallback(self, inMsg):
+        '''
+        A callback for incoming message that simply
+        prints the message. Used when a caller to
+        subscribeToTopic() explicitly specifies None
+        for the delivery callback. See also 
+        declaration of defaultResultCallback's partial
+        function object.
+        
+        :param inMsg: Any incoming message from the bus.
+        :type inMsg: BusMessage
+        '''
+        msgInfo = '%s (%s): %s' % (inMsg.isoTime, inMsg.topicName, inMsg.content)
+        print(msgInfo)
+
     def unsubscribeFromTopic(self, topicIdentifier=None):
         '''
         Unsubscribes from topic. Stops the topic's thread,
@@ -225,18 +246,22 @@ class BusAdapter(object):
         :param topicIdentifier: name of topic to subscribe from
         :type topicIdentifier: {string | None | pattern}
         '''
-        # Is pattern identifier an regex pattern?
-        try:
-            pattern_str = topicIdentifier.pattern
-            # Unsubscribing from a pattern:
-            self.pub_sub.punsubscribe(pattern_str)
-        except AttributeError:
-            # Regular string, not a pattern:
-            self.pub_sub.unsubscribe(topicIdentifier)
-            pattern_str = topicIdentifier
-        
         if topicIdentifier is None:
-            # Kill all topic threads:
+            # Unsubscribe from all:
+            
+            # First: unsubscribe from the redis server for all
+            # patterns and strings:
+            for topicId in self.mySubscriptions():
+                try:
+                    # topicId may be a string or a pattern instance:
+                    pattern_str = topicId.pattern
+                    # Unsubscribing from a pattern:
+                    self.pub_sub.punsubscribe(pattern_str)
+                except AttributeError:
+                    # Regular string, not a pattern instance:
+                    self.pub_sub.unsubscribe(topicId)
+                    
+            # Next: kill all topic threads:
             for deliveryThread in self.topicThreads.values():
                 deliveryThread.stop()
                 # Wait for thread to finish; timeout is a bit more
@@ -247,20 +272,35 @@ class BusAdapter(object):
                     raise TimeoutError("Unable to stop delivery thread '%s'." % deliveryThread.name)
 
             self.topicThreads = {}
-        else:
-            try:
-                self.topicThreads[pattern_str].stop()
-                # Wait for thread to finish; timeout is a bit more
-                # than the 'stop-looking-at-queue' timeout used to check
-                # for periodic thread stoppage:
-                self.topicThreads[topicIdentifier].join(JOIN_WAIT_TIME)
-                if self.topicThreads[topicIdentifier].is_alive():
-                    raise TimeoutError("Unable to stop topicThreads[%s] thread '%s'." %\
-                                       (topicIdentifier, self.topicThreads[topicIdentifier].name))
-                
-                del self.topicThreads[topicIdentifier]
-            except KeyError:
-                pass
+            return
+
+        # Caller passed in not None, but a pattern instance 
+        # or topic name:
+        # Is pattern identifier a regex pattern?
+        try:
+            pattern_str = topicIdentifier.pattern
+            # Unsubscribing from a pattern:
+            self.pub_sub.punsubscribe(pattern_str)
+        except AttributeError:
+            # Regular string, not a pattern:
+            self.pub_sub.unsubscribe(topicIdentifier)
+            pattern_str = topicIdentifier
+        
+        # Next: kill the topic thread associated with the
+        # pattern or string:
+        try:
+            self.topicThreads[pattern_str].stop()
+            # Wait for thread to finish; timeout is a bit more
+            # than the 'stop-looking-at-queue' timeout used to check
+            # for periodic thread stoppage:
+            self.topicThreads[topicIdentifier].join(JOIN_WAIT_TIME)
+            if self.topicThreads[topicIdentifier].is_alive():
+                raise TimeoutError("Unable to stop topicThreads[%s] thread '%s'." %\
+                                   (topicIdentifier, self.topicThreads[topicIdentifier].name))
+            
+            del self.topicThreads[topicIdentifier]
+        except KeyError:
+            pass
             
             
     def makeResponseMsg(self, incomingBusMsg, responseContent):
